pirate = {
    "build plate": "deck",
    "buildplate": "deck",
    "quit": "abandon ship",
    "back": "avast",
    "nozzle": "muzzle",
    "nozzles": "muzzles",
    "extruder": "cannon",
    "extruders": "cannons",
    "yes": "aye",
    "no": "nay",
    "loading": "haulin'",
    "you": "ye",
    "ok": "arrr",
    "machine": "ship",
    "machines": "ships",
    "mm/s²": "knots/s",
    "mm/s": "knots",
    "printer": "ship",
    "printers": "ships",
    "view": "spyglass",
    "support": "peg legs",
    "fan": "wind",
    "file": "treasure",
    "file(s)": "treasure(s)",
    "files": "treasures",
    "profile": "map",
    "profiles": "maps",
    "setting": "knob",
    "settings": "knobs",
    "shield": "sail",
    "your": "yer",
    "the": "th'",
    "travel": "sail",
    "wireframe": "ropey",
    "wire": "rope",
    "are": "be",
    "is": "be",
    "there": "thar",
    "not": "nay",
    "delete": "send to Davy Jones' locker",
    "remove": "send to Davy Jones' locker",
    "print": "scribble",
    "printing": "scribblin'",
    "load": "haul",
    "connect to": "board",
    "connecting": "boarding",
    "collects": "hoards",
    "prime tower": "buoy",
    "change log": "captain's log",
    "my": "me",
    "removable drive": "life boat",
    "print core": "scribbler",
    "printcore": "scribbler",
    "abort": ["maroon", "abandon"],
    "aborting": ["marooning", "abandoning"],
    "aborted": ["marooned", "abandoned"],
    "connected": ["anchored", "moored"],
    "developer": "scurvy dog",
    "wizard": "cap'n",
    "active leveling": "keelhauling",
    "download": "plunder",
    "downloaded": "plundered",
    "caution hot surface": "fire in the hole!",
    "type": "sort",
    "spool": "barrel",
}
